Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(64)

Unified Diff: Source/WebCore/rendering/svg/RenderSVGInlineText.cpp

Issue 7218014: Merge 87846 - 2011-06-01 Levi Weintraub <leviw@chromium.org> (Closed) Base URL: http://svn.webkit.org/repository/webkit/branches/chromium/782/
Patch Set: Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/WebCore/ChangeLog ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/WebCore/rendering/svg/RenderSVGInlineText.cpp
===================================================================
--- Source/WebCore/rendering/svg/RenderSVGInlineText.cpp (revision 89363)
+++ Source/WebCore/rendering/svg/RenderSVGInlineText.cpp (working copy)
@@ -235,15 +235,15 @@
Document* document = renderer->document();
ASSERT(document);
-
+
CSSStyleSelector* styleSelector = document->styleSelector();
ASSERT(styleSelector);
// Alter font-size to the right on-screen value, to avoid scaling the glyphs themselves.
AffineTransform ctm;
SVGImageBufferTools::calculateTransformationToOutermostSVGCoordinateSystem(renderer, ctm);
scalingFactor = narrowPrecisionToFloat(sqrt((pow(ctm.xScale(), 2) + pow(ctm.yScale(), 2)) / 2));
- if (scalingFactor == 1 || !scalingFactor) {
+ if (scalingFactor == 1 || !scalingFactor || style->fontDescription().textRenderingMode() == GeometricPrecision) {
scalingFactor = 1;
scaledFont = style->font();
return;
@@ -235,15 +235,15 @@
CSSStyleSelector* styleSelector = document->styleSelector();
ASSERT(styleSelector);
- // Alter font-size to the right on-screen value, to avoid scaling the glyphs themselves.
+ // Alter font-size to the right on-screen value to avoid scaling the glyphs themselves, except when GeometricPrecision is specified
AffineTransform ctm;
SVGImageBufferTools::calculateTransformationToOutermostSVGCoordinateSystem(renderer, ctm);
« no previous file with comments | « Source/WebCore/ChangeLog ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698